const path = require("path");
require("dotenv").config({ path: path.resolve(__dirname, ".env") });
const express = require("express");
const connectDB = require("./db");
const cors = require("cors");
const authRoutes = require("./routes/authRoutes");
const userRoutes = require("./routes/userRoutes");
const propertyRoutes = require("./routes/propertyRoutes");
const categoryRoutes = require("./routes/categoryRoutes");
const areaSizeRoutes = require('./routes/areaSizeRoutes');
const propertyTypeRoutes = require('./routes/propertyTypeRoutes');

const app = express();
app.use(express.json({ limit: '10mb' }));
app.use(express.urlencoded({ limit: '10mb', extended: true }));
app.use(express.urlencoded({ extended: true }));
app.use(cors());
app.use('/', express.static(__dirname + '/public'));
app.use(express.json());
app.use("/api/auth", authRoutes);
app.use("/api/users", userRoutes);
app.use("/api/categories", categoryRoutes);
app.use("/api/properties", propertyRoutes);
app.use('/api/area-sizes', areaSizeRoutes);
app.use('/api/property-types', propertyTypeRoutes);
app.get('/*', (req, res) => {
  const filePath = path.resolve(__dirname, 'public', 'index.html');
  res.sendFile(filePath);
});
connectDB();
const PORT = process.env.PORT || 5000;
app.listen(PORT, () => console.log(`Server running on port ${PORT}`));